%define fc4 1
# Define fc4 1 if the system is FC4-based

%define x86_64 0
# Define x86_64 if you want to build for x86_64

%define smp 1
# Define smp 1 if the system is SMP-based

%if %{?smp}
   %define kernel    %(echo `uname -r` | sed -e s/smp//g)
   %define kernels   %{kernel} %{kernel}smp
%else
   %define kernel    %(echo `uname -r`)
   %define kernels   %{kernel}
%endif

%define pkgrel  5

%define module          qvm86.ko 
%define qvm86_name      kernel-module-qvm86
# See http://fedoraproject.org/wiki/PackageNamingGuidelines

%define qvm86_version   cvs20060103
%define qvm86_release   %{pkgrel}%{?dist}.%(echo %{kernel} | sed -e s/-/_/g)

%define qemu_version    0.8.0
%define qemu_release    %{pkgrel}%{?dist}

Name : qemu 
Version : %{qemu_version}
Release : %{qemu_release} 
# Seehttp://fedoraproject.org/wiki/DistTag

License: LGPL, GPL
Summary: A generic and open source processor emulator.
Group: Applications/Emulators

URL: http://fabrice.bellard.free.fr/qemu/

BuildRoot: %{_tmppath}/%{name}-buildroot
Source0: %{name}-%{version}.tar.gz
Source1: qvm86-cvs-2006-01-03.tar.gz
Source2: qvm86.init
Patch0: qemu-Makefile.patch
Patch1: qemu-configure.patch
Patch2: qemu-no-strip.patch
Patch3: qemu-qvm86-3.patch
Patch4: qemu-title.patch
Patch5: qemu-initrd.patch

Requires: SDL
BuildRequires: SDL-devel
%if %{?fc4}
BuildRequires: compat-gcc-32
%endif
AutoReq: no
AutoProv: no

%description
QEMU is processor and system emulator which achieves a good emulation speed by 
using dynamic translation. It emulates a full system (for example a PC or a PowerMac) 
or runs Linux processes compiled for one processor on another.

%prep
rm -rf %{buildroot}

%setup -q
%patch0

# patch1 (qemu-configure.patch) only needed in FC4
# make sure to install compat-gcc-32
%if %{?fc4}
%patch1
%endif

# Disable stripping of binaries so debuginfo works
%patch2 -p1

tar zxf %{SOURCE1} -C %{_builddir}/%{name}-%{version}

%patch3 -p1
%patch4 -p1
%patch5 -p1

%build
for kernel in %{kernels}
do
  %if %{?x86_64}
    ./configure --prefix=/usr --interp-prefix=/usr/lib/gnemul/qemu-%M --enable-alsa --enable-qvm86 --cc=gcc32 --host-cc=gcc32 --enable-adlib
  %else
    ./configure --prefix=/usr --interp-prefix=/usr/lib/gnemul/qemu-%M --enable-alsa --enable-qvm86 --enable-adlib
  %endif
  make %{?_smp_mflags}
# See http://fedoraproject.org/wiki/PackagingGuidelines#parallelmake
  cd qvm86
  mv %{module} $kernel-%{module}
  make clean
  cd -
done

%install
make install \
  prefix=%{buildroot}/usr \
  bindir=%{buildroot}/usr/bin \
  datadir=%{buildroot}/usr/share/qemu \
  docdir=%{buildroot}/usr/share/doc/qemu \
  mandir=%{buildroot}/usr/share/man

for kernel in %{kernels}
do
  mkdir -p %{buildroot}/lib/modules/${kernel}/misc
  install -m 644  qvm86/$kernel-%{module} %{buildroot}/lib/modules/$kernel/misc/%{module}
done

mkdir -p %{buildroot}/etc/rc.d/init.d
install -m 755 %{SOURCE2} %{buildroot}/etc/rc.d/init.d/qvm86

#################################
# subpackage : kernel-module-qemu
#################################
%package -n %{qvm86_name}
Version   : %{qvm86_version}
Release   : %{qvm86_release}
License   : GPL
Summary   : The QEMU Accelerator Module (QVM86)
Group     : Applications/Emulators
Requires  : qemu = %{qemu_version}-%{qemu_release}

%description -n %{qvm86_name}
The QVM86 Accelerator Module increases the speed of QEMU when a PC is 
emulated on a PC. It runs most of the target application code directly 
on the host processor to achieve near native performance. 

%post -n %{qvm86_name}
/sbin/chkconfig --add qvm86
/sbin/service qvm86 restart > /dev/null 2>&1 || :
if [ "$1" = 1 ]; then
	grep '^qemu:' /etc/group 1>/dev/null 2>&1 || groupadd -r qemu
fi

%preun -n %{qvm86_name}
if [ "$1" = 0 ]; then
        /sbin/service qvm86 stop > /dev/null 2>&1 || :
        /sbin/chkconfig --del qvm86
fi 

%files -n %{qvm86_name}
%defattr(-,root,root)
%doc qvm86/GPL qvm86/README qvm86/ChangeLog
/etc/rc.d/init.d/qvm86
/lib/modules/*/misc/%{module}


%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root)
%doc Changelog COPYING COPYING.LIB LICENSE README README.distrib TODO VERSION
%{_bindir}/qemu*
%{_docdir}/qemu
%{_mandir}/man1/qemu*
%{_datadir}/qemu

%changelog
* Mon Feb  6 2006  <berrange@redhat.com> 0.8.0-5
- Cleanup specfile a little

* Tue Jan 10 2006 Daniel Berrange <berrange@redhat.com> 0.8.0-4
- Add the 'qemu' group in post install scriptlet
- Update qvm86 init script to 'chgrp qemu /dev/qvm86'

* Tue Jan  3 2006 Daniel Berrange <berrange@redhat.com> 0.8.0-2
- Removed kqemu since its non-redistributable, and replaced with qvm86

* Wed Dec 21 2005 Thomas Chung <tchung@fedoranews.org> 0.8.0-1
- qemu version 0.8.0

* Thu Oct 20 2005 Thomas Chung <tchung@fedoranews.org> 0.7.2-4
- Sync {qemu_release} and {kqemu_release}

* Fri Oct 07 2005 Robin Green <greenrd@greenrd.org> 0.7.2-3
- Made x86_64 support conditional
- Fixed bug that kqemu was not remade for SMP kernels

* Sat Sep 24 2005 Thomas Chung <tchung@fedoranews.org> 0.7.2-2
- Fix kqemu init script starting issue

* Sun Sep 04 2005 Thomas Chung <tchung@fedoranews.org> 0.7.2-1
- Version 0.7.2
- Patch #2 (kqemu-linux.patch) no longer needed

* Fri Sep 02 2005 Thomas Chung <tchung@fedoranews.org> 0.7.1-3
- Use {?smp} to define SMP kernel or not
- Use {?fc4} to defind FC4 system or not

* Thu Jul 28 2005 Thomas Chung <tchung@fedoranews.org> 0.7.1-2
- Patch qemu-configure to use gcc32 for FC4
- Patch kqemu-linux.c to fix Unknown symbol __PAGE_KERNEL_EXEC
- Use {?_smp_mflags} to speed up builds and especially on SMP machines

* Wed Jul 27 2005 Thomas Chung <tchung@fedoranews.org> 0.7.1-1
- Version 0.7.1
- Change kernel-modules-qemu to kernel-module-qemu to comply with
  Fedora Project Package Naming Guidelines
  See http://fedoraproject.org/wiki/PackageNamingGuidelines
- Use Obsoletes kernel-modules-qemu

* Mon Jun 20 2005 Thomas Chung <tchung@fedoranews.org> 0.7.0-5
- Use {?dist} in qemu release
- Requires SDL
- BuildRequires SDL-devel

* Sun May 22 2005 Thomas Chung <tchung@fedoranews.org> 0.7.0-4
- Create an init script for kqemu
- Build kernel-modules-qemu for the latest installed kernels

* Thu May 19 2005 Thomas Chung <tchung@fedoranews.org> 0.7.0-3
- Rename qemu-accelerator to kernel-modules-qemu

* Wed May 18 2005 Thomas Chung <tchung@fedoranews.org> 0.7.0-2
- Splits package into subpackage qemu-accelerator

* Tue May 17 2005 Thomas Chung <tchung@fedoranews.org> 0.7.0-1
- Includes QEMU Accelerator Module

* Mon May 16 2005 Thomas Chung <tchung@fedoranews.org> 0.7.0-0
- Initial RPM build

